# Changelog

## Unreleased
### Changed
### Added

## [0.1.1] - 2024-11-06

### Changed

* Update docs

### Added

* Add `_many` functions
* Add badges to docs + readme

## [0.1.0] - 2024-11-05

First release 🚀
